@@ -1,4 +1,5 @@
 import logging
+import stat
 import re
 import os
 import argparse
@@ -179,6 +180,7 @@ def update_authorized_keys():
 
     # Write authorized_keys
     fd = open(os.path.join(home_path, '.ssh', 'authorized_keys'), 'w')
+    os.fchmod(fd, stat.S_IRUSR | stat.S_IWUSR)
     fd.write(authorized_keys)
     fd.close()
 
